штат=['директор','бухгалтер','программист','охранник','программист',
'менеджер','менеджер','программист','уборщица','уборщица','охранник']
штат.sort()
i,s=0,[]
while i<len(штат):
    n,j=1,i+1
    while j<len(штат):
        if штат[i]==штат[j]:
            n+=1
            del штат[j]
        else: j+=1
    s.append(n)
    i+=1
print(штат,s)
