import numpy as np

# Создание массива x от -5 до 5 с шагом 0.1
x = np.arange(-5, 5, 0.1)

# Вычисление массива y по формуле y = 2x^2 + 4
y = 2 * x**2 + 4

# Нахождение минимального значения y
min_y = np.min(y)

print("Массив y:", y)
print("Минимальное значение y:", min_y)
